@@ -12,11 +12,11 @@ and a lightweight markup language for stories, novels and other fiction.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
 
 =head1 SYNOPSIS
 
@@ -31,9 +31,9 @@ fiction (= stories, novels, novellas, etc.). What it does is:
 
 =over 4
 
-=item 1. Converting a well-formed plain text format to a specialized XML format.
+=item 1. Convert a well-formed plain text format to a specialized XML format.
 
-=item 2. Converting the XML to DocBook/XML or directly to HTML for rendering.
+=item 2. Convert the XML to DocBook/XML or directly to HTML for rendering.
 
 =back
 
@@ -169,10 +169,18 @@ Examples can be found in the C<t/data> directory, and here:
 
 =over 4
 
-=item * The Pope Died on Sunday
+=item * The Pope Died on Sunday (Hebrew version)
 
 L<http://www.shlomifish.org/humour/Pope/>
 
+=item * The Enemy and How I Helped to Fight it (Hebrew version)
+
+L<http://www.shlomifish.org/humour/TheEnemy/>
+
+=item * The Human Hacking Field Guide (Hebrew version)
+
+L<http://www.shlomifish.org/humour/human-hacking/>
+
 =back
 
 =head1 AUTHOR
@@ -213,6 +221,10 @@ You can also look for information at:
 
 =over 4
 
+=item * XML-Grammar-Fiction’s Homepage
+
+L<http://www.shlomifish.org/open-source/projects/XML-Grammar/Fiction/>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/XML-Grammar-Fiction>
@@ -225,6 +237,10 @@ L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction>
 
+=item * MetaCPAN
+
+L<https://metacpan.org/release/XML-Grammar-Fiction>
+
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/XML-Grammar-Fiction>
