@@ -8,7 +8,7 @@ use Carp;
 use HTML::Entities ();
 use XML::Writer;
 
-use Mouse;
+use MooX 'late';
 
 extends("XML::Grammar::FictionBase::TagsTree2XML");
 
@@ -25,11 +25,11 @@ text representing prose to an XML format.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
 
 =head2 new()
 
