@@ -3,7 +3,7 @@ package XML::Grammar::Fiction::FromProto::Parser;
 use strict;
 use warnings;
 
-use Mouse;
+use MooX 'late';
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ B<For internal use only>.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
 
 =head1 AUTHOR
 
