@@ -3,7 +3,7 @@ package XML::Grammar::Fiction::Struct::Tag;
 use strict;
 use warnings;
 
-use Mouse;
+use MooX 'late';
 
 use List::MoreUtils;
 
@@ -18,11 +18,11 @@ B<For internal use only>.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
 
 has 'name' => (is => "rw", isa => "Str");
 has 'line' => (is => "rw", isa => "Int");
@@ -68,7 +68,7 @@ sub detach_children
 
 package XML::Grammar::Fiction::Struct::Tag::Para;
 
-use Mouse;
+use MooX 'late';
 
 extends("XML::Grammar::Fiction::Struct::Tag");
 
