@@ -5,7 +5,7 @@ use warnings;
 
 use Carp;
 
-use Mouse;
+use MooX 'late';
 
 extends ("XML::Grammar::Fiction::RNG_Renderer");
 
@@ -18,11 +18,13 @@ DocBook 5.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
+
+=head1 METHODS
 
 =head2 new()
 
@@ -33,6 +35,10 @@ at that point.
 
 Internal - (to settle pod-coverage.).
 
+=head2 xslt_transform_basename()
+
+Inherited - (to settle pod-coverage).
+
 =cut
 
 
