@@ -5,7 +5,7 @@ use warnings;
 
 use Carp;
 
-use Mouse;
+use MooX 'late';
 
 extends( 'XML::Grammar::Fiction::RNG_Renderer' );
 
@@ -15,11 +15,17 @@ XML::Grammar::Fiction::ToHTML - module that converts the Fiction-XML to HTML.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
+
+=head1 METHODS
+
+=head2 xslt_transform_basename()
+
+Inherited - (to settle pod-coverage).
 
 =head2 new()
 
