@@ -11,7 +11,7 @@ use File::ShareDir ':ALL';
 use XML::LibXML;
 use XML::LibXSLT;
 
-use Mouse;
+use MooX 'late';
 
 has '_data_dir' => (isa => 'Str', is => 'rw');
 has '_data_dir_from_input' => (isa => 'Str', is => 'rw', init_arg => 'data_dir',);
@@ -28,11 +28,13 @@ file to a different XML file using an XSLT transform.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
+
+=head1 METHODS
 
 =head2 new()
 
@@ -47,6 +49,14 @@ Internal - (to settle pod-coverage.).
 
 Internal - (to settle pod-coverage.).
 
+=head2 rng_schema_basename()
+
+Inherited - (to settle pod-coverage.).
+
+=head2 xslt_transform_basename()
+
+Inherited - (to settle pod-coverage.).
+
 =cut
 
 sub BUILD
