@@ -2,7 +2,7 @@ package XML::Grammar::Screenplay::FromProto;
 
 use XML::Writer;
 
-use Mouse;
+use MooX 'late';
 
 extends("XML::Grammar::FictionBase::TagsTree2XML");
 
@@ -15,11 +15,11 @@ text representing a screenplay to an XML format.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
 
 =head2 new()
 
