@@ -1,6 +1,6 @@
 package XML::Grammar::Screenplay::ToHTML;
 
-use Mouse;
+use MooX 'late';
 
 extends('XML::Grammar::Screenplay::XSLT::Base');
 
@@ -13,11 +13,17 @@ XML to HTML.
 
 =head1 VERSION
 
-Version 0.9.3
+Version 0.10.0
 
 =cut
 
-our $VERSION = '0.9.3';
+our $VERSION = '0.10.0';
+
+=head1 METHODS
+
+=head2 xslt_transform_basename()
+
+Inherited - (to settle pod-coverage).
 
 =head2 new()
 
